diff --git a/README.md b/README.md
index 38e43f6..291ea1c 100644
--- a/README.md
+++ b/README.md
@@ -19,7 +19,7 @@
-
+
or read the change log
diff --git a/src/webviews/apps/home/components/header-card.ts b/src/webviews/apps/home/components/header-card.ts
index bdf7027..a3f08da 100644
--- a/src/webviews/apps/home/components/header-card.ts
+++ b/src/webviews/apps/home/components/header-card.ts
@@ -9,7 +9,7 @@ const template = html`
diff --git a/src/webviews/apps/home/home.html b/src/webviews/apps/home/home.html
index ec0ddb6..749cb20 100644
--- a/src/webviews/apps/home/home.html
+++ b/src/webviews/apps/home/home.html
@@ -86,7 +86,7 @@
- Welcome to GitLens 12
+ Welcome to GitLens 13
GitLens supercharges Git inside VS Code and unlocks the untapped knowledge within each
repository.
diff --git a/src/webviews/apps/welcome/welcome.html b/src/webviews/apps/welcome/welcome.html
index 0797d70..0a992b4 100644
--- a/src/webviews/apps/welcome/welcome.html
+++ b/src/webviews/apps/welcome/welcome.html
@@ -40,7 +40,7 @@
- Welcome to GitLens 12
+ Welcome to GitLens 13
diff --git a/src/plus/subscription/subscriptionService.ts b/src/plus/subscription/subscriptionService.ts
index 530ffee..f0abb28 100644
--- a/src/plus/subscription/subscriptionService.ts
+++ b/src/plus/subscription/subscriptionService.ts
@@ -90,8 +90,8 @@ export class SubscriptionService implements Disposable {
);
const subscription = this.getStoredSubscription();
- // Resets the preview trial state on the upgrade to 12.2
- if (subscription != null && satisfies(previousVersion, '< 12.2')) {
+ // Resets the preview trial state on the upgrade to 13.0
+ if (subscription != null && satisfies(previousVersion, '< 13.0')) {
subscription.previewTrial = undefined;
}